#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/ip_update-update.sh - paramater update script
#
# Creation   : 2008-12-29 christian
# Last update: $Id: ip_update-update.sh 21 2009-01-15 16:50:59Z root $
#
# Copyright (c) 2009 Christian Richter, <richterch(at)gmx(dot)de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/ip_update-update-trace$$.log
#set -x

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

# set packages name
packageName=ip_update

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
START_IP_UPDATE='no'

IP_UPDATE_DATE='%d.%m.%y'
IP_UPDATE_TIME='%H:%M:%S'
IP_UPDATE_EMAIL='foo@foo.de'
IP_UPDATE_NAME='yourname'
IP_UPDATE_MODE='fritzbox'
IP_UPDATE_IPADRESS='192.168.178.1'

IP_UPDATE_USE_FTP='no'
IP_UPDATE_FTP_N='1'
IP_UPDATE_FTP_1_SRV='www.foo.de'
IP_UPDATE_FTP_1_USR='yourname'
IP_UPDATE_FTP_1_PWD='pass'
IP_UPDATE_FTP_1_TMP='/usr/local/ip_update/ip_update_1.txt'
IP_UPDATE_FTP_1_HTM='dynip.htm'
IP_UPDATE_FTP_1_PASSIVE='no'

IP_UPDATE_USE_SFTP='no'
IP_UPDATE_SFTP_N='1'
IP_UPDATE_SFTP_1_SRV='www.foo.de'
IP_UPDATE_SFTP_1_USR='yourname'
IP_UPDATE_SFTP_1_PWD='pass'
IP_UPDATE_SFTP_1_TMP='/usr/local/ip_update/ip_update.txt'
IP_UPDATE_SFTP_1_HTM='dynip.htm'

IP_UPDATE_CRON='*/30 * * * *'        # cron configuration string
# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
renameOldVariables()
{
    # read old values
    if [ -f /etc/config.d/ip_update ]
    then
        . /etc/config.d/ip_update
    fi

}

# ----------------------------------------------------------------------------
# Write config and default files
# ----------------------------------------------------------------------------
makeConfigFile()
{
    internal_conf_file=${1}
    {
    # ------------------------------------------------------------------------
    printgpl -conf ip_update "2008-12-29" "christian"
    # ------------------------------------------------------------------------


    # ------------------------------------------------------------------------
    printgroup "Basic configuration"
    # ------------------------------------------------------------------------
    printvar "START_IP_UPDATE" "Use: yes or no"
    printvar "IP_UPDATE_DATE" "format for the date in the upload file"
    printvar "IP_UPDATE_TIME" "format for the time in the upload file"
    printvar "IP_UPDATE_EMAIL" "your email which was shown on the uploaded file"
    printvar "IP_UPDATE_NAME" "your name which was shown on the uploaded file"
    printvar "IP_UPDATE_MODE" "fritzbox, internet, isdn, dsl"
    printvar "IP_UPDATE_IPADRESS" "ip-adress of the fritzbox"

    #-------------------------------------------------------------------------
    printgroup "FTP configuration"
    #-------------------------------------------------------------------------
    printvar "IP_UPDATE_USE_FTP" "Use: yes or no"
    echo
    printvar "IP_UPDATE_FTP_N" "number of ftp-server"
    # begin ftp
    idx=1
    while [ "${idx}" -le "${IP_UPDATE_FTP_N}" ]
    do
        printvar "IP_UPDATE_FTP_${idx}_SRV" "name of the ftp-server"
        printvar "IP_UPDATE_FTP_${idx}_USR" "username"
        printvar "IP_UPDATE_FTP_${idx}_PWD" "password"
        printvar "IP_UPDATE_FTP_${idx}_TMP" "draft file"
        printvar "IP_UPDATE_FTP_${idx}_HTM" "path and name of the file on the ftp-server"
        printvar "IP_UPDATE_FTP_${idx}_PASSIVE" "passive Mode yes or no"
        idx=`/usr/bin/expr ${idx} + 1`
    done

    #-------------------------------------------------------------------------
    printgroup "SFTP configuration"
    #-------------------------------------------------------------------------
    printvar "IP_UPDATE_USE_SFTP" "use sftp upload"
    echo
    printvar "IP_UPDATE_SFTP_N" "number of sftp-server"
    idx=1
    while [ "${idx}" -le "${IP_UPDATE_SFTP_N}" ]
    do
        printvar "IP_UPDATE_SFTP_${idx}_SRV" "name of the ftp-server"
        printvar "IP_UPDATE_SFTP_${idx}_USR" "username"
        printvar "IP_UPDATE_SFTP_${idx}_PWD" "password"
        printvar "IP_UPDATE_SFTP_${idx}_TMP" "draft file"
        printvar "IP_UPDATE_SFTP_${idx}_HTM" "path and name of the file on the ftp-server"
        idx=`/usr/bin/expr ${idx} + 1`
    done
    #-------------------------------------------------------------------------
    printgroup "Cron configuration"
    #-------------------------------------------------------------------------
    printvar "IP_UPDATE_CRON" "cron configuration string"

    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
makeCheckFile()
{
    printgpl -check ip_update '2008-12-29' 'christian' >/etc/check.d/ip_update
    cat >> /etc/check.d/ip_update <<EOFG
# Variable                  OPT_VARIABLE       VARIABLE_N        VALUE
START_IP_UPDATE             -                  -                 YESNO
IP_UPDATE_DATE              START_IP_UPDATE    -                 DATE
IP_UPDATE_TIME              START_IP_UPDATE    -                 TIME
IP_UPDATE_MODE              START_IP_UPDATE    -                 IP_UPDATE_CHOOSE_MODE_CUI
IP_UPDATE_EMAIL             START_IP_UPDATE    -                 EMAILADDR
IP_UPDATE_NAME              START_IP_UPDATE    -                 NONE
IP_UPDATE_IPADRESS          START_IP_UPDATE    -                 EIPADDR
IP_UPDATE_USE_FTP           START_IP_UPDATE    -                 YESNO
IP_UPDATE_FTP_N             IP_UPDATE_USE_FTP  -                 NUMERIC
IP_UPDATE_FTP_%_SRV         IP_UPDATE_USE_FTP  IP_UPDATE_FTP_N   NOTEMPTY
IP_UPDATE_FTP_%_USR         IP_UPDATE_USE_FTP  IP_UPDATE_FTP_N   NOTEMPTY
IP_UPDATE_FTP_%_PWD         IP_UPDATE_USE_FTP  IP_UPDATE_FTP_N   PASSWD
IP_UPDATE_FTP_%_TMP         IP_UPDATE_USE_FTP  IP_UPDATE_FTP_N   ABS_PATH
IP_UPDATE_FTP_%_HTM         IP_UPDATE_USE_FTP  IP_UPDATE_FTP_N   NOTEMPTY
IP_UPDATE_FTP_%_PASSIVE     IP_UPDATE_USE_FTP  IP_UPDATE_FTP_N   YESNO
IP_UPDATE_USE_SFTP          START_IP_UPDATE    -                 YESNO
IP_UPDATE_SFTP_N            IP_UPDATE_USE_SFTP -                 NUMERIC
IP_UPDATE_SFTP_%_SRV        IP_UPDATE_USE_SFTP IP_UPDATE_SFTP_N  NOTEMPTY
IP_UPDATE_SFTP_%_USR        IP_UPDATE_USE_SFTP IP_UPDATE_SFTP_N  NOTEMPTY
IP_UPDATE_SFTP_%_PWD        IP_UPDATE_USE_SFTP IP_UPDATE_SFTP_N  PASSWD
IP_UPDATE_SFTP_%_TMP        IP_UPDATE_USE_SFTP IP_UPDATE_SFTP_N  ABS_PATH
IP_UPDATE_SFTP_%_HTM        IP_UPDATE_USE_SFTP IP_UPDATE_SFTP_N  NOTEMPTY
IP_UPDATE_CRON              START_IP_UPDATE    -                 CRONTAB
EOFG

    # Set rights for check.d file
    chmod 0600 /etc/check.d/ip_update
    chown root /etc/check.d/ip_update


    printgpl -check_exp ip_update '2008-12-29' 'christian' >/etc/check.d/ip_update.exp
    cat >> /etc/check.d/ip_update.exp <<EOFG
DATE                      = '(%d.%m.%y|%y/%m/%d|%d-%m-%y)'
                          : 'only %d.%m.%y or %y/%m/%d or %d-%m-%y are allowed'
TIME                      = '(%H:%M:%S|%H:%M)'
                          : 'only %H:%M:%S or %H:%M are allowed'
IP_UPDATE_CHOOSE_MODE_CUI = 'fritzbox|internet|isdn|dsl'
                          : 'only fritzbox, internet, isdn or dsl allowed'

EOFG

    # Set rights for check.exp file
    chmod 0600 /etc/check.d/ip_update.exp
    chown root /etc/check.d/ip_update.exp


    printgpl -check_ext ip_update '2008-12-29' 'christian' >/etc/check.d/ip_update.ext
    cat >> /etc/check.d/ip_update.ext <<EOFG
if ( ip_update_mode == "fritzbox" && ip_update_ipadress == "" )
then
   error "IP_UPDATE_IPADRESS is empty!"
fi

EOFG

    # Set rights for check.ext file
    chmod 0600 /etc/check.d/ip_update.ext
    chown root /etc/check.d/ip_update.ext
}



# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
# Write default config file
if [ -f /etc/config.d/ip_update ]
then
    mecho -info -n "Updating configuration. "
else
    mecho -info -n "creating configuration. "
fi

makeConfigFile /etc/default.d/ip_update

# Update from old version
mecho -info -n "."
renameOldVariables

# Write new config file
mecho -info -n "."
makeConfigFile /etc/config.d/ip_update

# Write check.d file
mecho -info -n "."
makeCheckFile

mecho -info "Finished."

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------